@@ -21,8 +21,8 @@ class App(Base):
       self._socket = sock.makefile()
       Helper.write_hash_to_file({"language":"python", "name":self._name, "flow_type":"app", "multilang_version":VERSION}, self._socket)
 
-  def source(self, name=None, matches=None, options={}, emits=None, end_cycle_policy="null_emit", prepare=None, begin_cycle=None, next_tuple=None):
-    return Base._source_common(self, Stream, name, matches, options, emits, end_cycle_policy, prepare, begin_cycle, next_tuple)
+  def source(self, *args, **kwargs):
+    return Base._source_common(self, Stream, *args, **kwargs)
 
   def call_component(self, *args, **kwargs):
     return Base._call_component_common(self, None, Stream, *args, **kwargs)
